% fig3p1.m
% Display power spectra of BPSK phasor waveform and signal waveform.

clfigs
if exist('printon') ~= 1, printon = 0; end

imax = 200;
bitrate = 20;
cfreq = 100;
f = [-(imax+cfreq):(imax+cfreq)] * pi / bitrate + 1e-6;
p = (sin(f) ./ f);
psq = p .* p;
ssq = psq(1:(2*imax+1)) + psq((2*cfreq+1):(2*cfreq+2*imax+1));

setfig(1)
plot ([0 0],[1.5 -1.6],':r',[-imax imax],[0 0],':r',....
 [-imax imax],[-1.5 -1.5],':r',[-cfreq -cfreq],[-0.3 -1.6],':r',....)
 [cfreq cfreq],[-0.3 -1.6],':r')
axis('normal')
axis([-imax imax -2 1.5])
axis('off')
set(gca,'Xtick',[],'Ytick',[]);
set(gca,'position',[0.05 0.1 0.9 0.8]);
hold on
plot([-5 5],[1 1],'-r');
plot([1:3; 1:3]*bitrate,[-1;1]*[1 1 1]*0.05,'-r');
plot ([-imax:imax], psq([0:2*imax]+cfreq+1), '-b');
plot ([-imax:imax], ssq - 1.5, '-k');
hold off

set(gcf,'DefaultTextFontSize',14)

latext(10,1,'$a_0^2 $T_$b','l',14);

latext(bitrate,-0.07,'1\/$T_$b','t',14);
latext(2*bitrate,-0.07,'2\/$T_$b','t',14);
latext(3*bitrate,-0.07,'3\/$T_$b','t',14);

latext(-cfreq,-1.6,'-$f_$c','t',14);
latext(cfreq,-1.6,'$f_$c','t',14);
latext(0,-1.6,'0','t',14);

latext(-imax,0.5,'|$P(\w)|^2','l',14);
latext(-imax,-1,'|$S(\w)|^2','l',14);

text(0.6*imax,-0.07,'freq','vert','top')
text(cfreq/2,-1.6,'freq','horiz','center','vert','top')

xlabel('Fig 3.1: Power spectra of random BPSK phasor and modulated signal.')

if printon,
  print -deps \1ngk\tex\e5mod\i5f3p1.eps
end
