% i5f3p3.m
% Display gaussian PDFs.

if exist('printon') ~= 1, printon = 0; end

imax = 200;
sdev = 70;
offset = 100;
x = [-(imax+offset):(imax+offset)] / sdev;
pdf = exp(-0.5 * (x .* x));

% Plot axes.
setfig(2)
plot ([0 0],[1.3 -0.2],':r',[-imax imax],[0 0],':r',....
 [-offset -offset],[1.6 -0.2],':r',[offset offset],[1.6 -0.2],':r')
axis('normal')
axis([-imax imax -0.5 2])
axis('off')
set(gca,'Xtick',[],'Ytick',[]);
set(gca,'position',[0.05 0.1 0.9 0.8]);
hold on

% Fill area under curve representing prob of error.
t = [5:5:imax];
plot([1;1]*t,[0;1]*pdf(t+2*offset+imax),':k');

% Plot 2 gaussian pdfs.
plot ([-imax:imax], pdf(1:(2*imax+1)), '--b');
plot ([-imax:imax], pdf((2*offset+1):(2*imax+2*offset+1)), '-k');
hold off

set(gcf,'DefaultTextHoriz','center','DefaultTextVert','baseline',...
  'DefaultTextFontSize',14);
text(-offset,1.7,'-1 Signal Voltage');
text(offset,1.7,'+1 Signal Voltage');
text(0,1.4,'Threshold');

latext(-offset,-0.2,'-$v_$s','t',14);
latext(offset,-0.2,'$v_$s','t',14);
latext(0,-0.2,'0','t',14);

latext(-1.5*offset,1,'Gaussian PDF\\Std. dev. = \s','b',14);
line([-1.5*offset;-130],[1;pdf(270)],'color','y');
latext(0.5*offset,-0.35,'Probability of error = $Q($v_$s / \s)','t',14);
line([0.5;0.3]*offset,[-0.35;0.1],'color','y');

xlabel('Fig 3.3: Probability density functions of detected signal+noise.')

if printon,
  print -deps \1ngk\tex\e5mod\i5f3p3.eps
end

