% i5f3p5.m
% Plot error rates of PSK and QAM.

if exist('printon') ~= 1, printon = 0; end

xmax = 20;
ebno = [0:0.2:xmax];
x = exp(ebno * (log(10) / 20));
pbepsk = qfunc(x * sqrt(2));

figure;
setfig(gcf)
set(gcf,'DefaultTextFontSize',14)
set(gcf,'DefaultLineLineWidth',2)
semilogy(ebno, pbepsk, '-b')

axis('normal')
axis([0 xmax 1e-6 1])
set(gca,'position',[0.15 0.25 0.8 0.7]);
set(gca,'YColor','k')

% pause
hold on
pbedpsk = 2 * pbepsk .* (1 - pbepsk);
semilogy(ebno, pbedpsk, '-', 'color', [0 0.7 0])
m = 2;
M = 2^m;
pbe16qam = (2 * (1 - 1/M) / m) * qfunc(x * sqrt(6 * m / (M^2 - 1)));
semilogy(ebno, pbe16qam, '-k')
m = 3;
M = 2^m;
pbe64qam = (2 * (1 - 1/M) / m) * qfunc(x * sqrt(6 * m / (M^2 - 1)));
semilogy(ebno, pbe64qam, '-m')
hold off

grid

set(gcf,'DefaultTextFontSize',14)

text(ebno(45),pbepsk(45),'BPSK','vert','top','horiz','right','color','b');
text(ebno(47),pbepsk(47),'and QPSK','vert','top','horiz','right','color','b');
text(ebno(46),pbedpsk(46),'BPSK with','vert','bottom','color',[0 0.7 0]);
text(ebno(48),pbedpsk(48),'differential','vert','bottom','color',[0 0.7 0]);
text(ebno(50),pbedpsk(50),'coding','vert','bottom','color',[0 0.7 0]);
text(ebno(53),pbe16qam(53),'16-QAM','vert','bottom','color','k');
text(ebno(74),pbe64qam(74),'64-QAM','vert','bottom','color','m');

text(-2.5,8e-3,'Bit');
text(-2.5,4e-3,'error');
text(-2.5,2e-3,'rate');

xlabel('Energy per bit / Noise PSD, Eb / No (dB)')
text(10,3e-8,'Fig 3.5: Bit error rate curves for PSK and QAM.',...
 'horiz','center');

if printon,
  print -deps \1ngk\tex\e5mod\i5f3p5.eps
end
