% fig3p7.m
% Carrier PLL phase detector characteristic.

if exist('printon') ~= 1, printon = 0; end

imax = 400;
period = 200;

theta = ([1:imax]'-0.5)*2*pi/period;
i = cos(theta);
q = sin(theta);
sgni = sign(i);
qsgni = q .* sgni;

setfig(4)
plot([1;1]*[0:0.5:4],[-10.5;1.5]*ones(1,9),':r',...
  [0;4]*ones(1,4),[1;1]*[0:-3:-9],':r')
axis([-0.07 4.07 -13 1.5])
axis('normal')
axis('off')
set(gca,'Xtick',[],'Ytick',[]);
set(gca,'position',[0.15 0.15 0.8 0.8])
hold on
plot(theta/pi, [i  q-3  sgni-6  qsgni-9],'-')
hold off

set(gcf,'DefaultTextVert','baseline','DefaultTextHoriz','center',...
  'DefaultTextFontSize',14);

text(2,-12,'Phase error between s(t) and Carrier VCO');

gap = -0.1;
latext(gap,0,'$i','r',14);
latext(gap,-3,'$q','r',14);
latext(gap,-6,'sgn($i)','r',14);
latext(gap,-9,'$q sgn($i)','r',14);

gap = -10.7;
latext(0,gap,'0','t',14);
latext(1,gap,'\p','t',14);
latext(2,gap,'2\p','t',14);
latext(3,gap,'3\p','t',14);
latext(4,gap,'4\p','t',14);

xlabel('Fig 3.7: Phase detector characteristic of the Carrier Phase-Locked Loop.')

if printon,
  print -deps \1ngk\tex\e5mod\i5f3p7.eps
end

return
