
% fig4p3.m
% QPSK, OQPSK and MSK symbol timing and MSK phase plot.

if exist('printon') ~= 1, printon = 0; end

imax = 400;
period = 200;

theta = ([1:imax]'-0.5)*2*pi/period;
i = cos(theta);
q = sin(theta);
sgni = sign(i) * [1 -1];
sgnq = sign(q) * [1 -1];

setfig(4),clf

if 1,
plot([1;1]*[0:4],[-11.5;1.5]*ones(1,5),':r')
axis([-0.05 4.1 -12.3 1.5])
axis('normal')
axis('off')
set(gca,'Xtick',[],'Ytick',[]);
set(gca,'position',[0.15 0.15 0.75 0.8])
set(gca,'DefaultTextFontSize',14);
hold on
plot(theta/pi, [sgnq sgnq-7],'-b')
plot(theta/pi, [sgnq-3 sgni-10],'-c')
hold off

text(-0.05,0,'Re(p)','horiz','right','vert','middle')
text(-0.05,-3,'Im(p)','horiz','right','vert','middle')
text(-0.15,-1.5,'QPSK','horiz','right','vert','middle')

text(-0.05,-7,'Re(p)','horiz','right','vert','middle')
text(-0.05,-10,'Im(p)','horiz','right','vert','middle')
text(-0.15,-8.1,'Offset','horiz','right','vert','middle')
text(-0.15,-8.9,'QPSK','horiz','right','vert','middle')

xlabel('Fig 4.3: QPSK and Offset QPSK symbol timing.')
drawnow

latext(0.5,0,'$b_0');
latext(1.5,0,'$b_2');
latext(2.5,0,'$b_4');
latext(3.5,0,'$b_6');
latext(0.5,-3,'$b_1');
latext(1.5,-3,'$b_3');
latext(2.5,-3,'$b_5');
latext(3.5,-3,'$b_7');
% drawnow

latext(0.5,-7,'$b_0');
latext(1.5,-7,'$b_2');
latext(2.5,-7,'$b_4');
latext(3.5,-7,'$b_6');
latext(0.25,-10,'$b_-_1');
latext(1,-10,'$b_1');
latext(2,-10,'$b_3');
latext(3,-10,'$b_5');
latext(3.75,-10,'$b_7');
% drawnow

text(0,-11.5,'0','vert','top','horiz','center');
latext(1,-11.5,'$T_$s','t');
latext(2,-11.5,'2$T_$s','t');
latext(3,-11.5,'3$T_$s','t');
latext(4,-11.5,'4$T_$s','t');

drawnow

if printon,
  print -deps \1ngk\tex\3f4digmod\3f4f4p3.eps
else
  pause
end

end

setfig(5),clf
plot([1;1]*[0:4],[-11.5;4]*ones(1,5),':r')
axis([-0.05 4.1 -12.3 4])
axis('normal')
axis('off')
set(gca,'Xtick',[],'Ytick',[]);
set(gca,'position',[0.15 0.15 0.75 0.8])
set(gca,'DefaultTextFontSize',14);
hold on
plot(theta/pi, [q*[1 -1]-7 i-10],'-c')
t = (period/4):imax;
plot(theta(t)/pi, -i(t)-10,'-c')

plot([[0:7]/2;4*ones(1,8)],[[0:7]/2;[-4:3]],'-m');
plot([[0:7]/2;4*ones(1,8)],-[[0:7]/2;[-4:3]],'-m');
plot([0;4]*[1 1],[1;1]*[1 -1],':r');

% Plot a typical phase path and its i,q components.
dphi = reshape(ones(50,1) * [1 -1 -1 -1 1 1 -1 1],400,1);
phi = [0; cumsum(dphi*pi/100)];
plot([0:400]/100,[phi/pi  sin(phi)-7  cos(phi)-10],'-b','linewidth',2)
hold off

text(1,2.5,'Phase Trellis','horiz','center','vert','middle')
text(-0.05,0,'0','horiz','right','vert','middle')
xlabel('Fig 4.4: MSK phase trellis and symbol timing.')
text(-0.05,2,'Phase(p)','horiz','right','vert','middle')
text(-0.05,-7,'Im(p)','horiz','right','vert','middle')
text(-0.05,-10,'Re(p)','horiz','right','vert','middle')
text(-0.15,-8.5,'MSK','horiz','right','vert','middle')
drawnow

latext(-0.05,1,'\p','r');
latext(-0.05,-1,'-\p','r');
latext(2,2,'2\p','br');
latext(2,-2,'-2\p','tr');
latext(3,3,'3\p','br');
latext(3,-3,'-3\p','tr');

latext(0.5,-7,'$b_0');
latext(1.5,-7,'$b_2');
latext(2.5,-7,'$b_4');
latext(3.5,-7,'$b_6');
latext(0.25,-10,'$b_-_1');
latext(1,-10,'$b_1');
latext(2,-10,'$b_3');
latext(3,-10,'$b_5');
latext(3.75,-10,'$b_7');

text(0,-11.5,'0','vert','top','horiz','center');
latext(1,-11.5,'2$T_$b','t');
latext(2,-11.5,'4$T_$b','t');
latext(3,-11.5,'6$T_$b','t');
latext(4,-11.5,'8$T_$b','t');

drawnow

if printon,
  print -deps \1ngk\tex\3f4digmod\3f4f4p4.eps
end

return

