% 3F4 Fig 4.5: Power Spectra for QPSK, MSK, 0.5R GMSK, 0.3R GMSK
% and 0.2R GMSK.

if exist('printon') ~= 1, printon = 0; end

setfig(6)
set(gcf,'DefaultTextFontSize',14);

N=512; Ts=8; 

% To plot GMSK spectrum use:
t0 = sqrt(log(2) / (2 * pi)) * Ts / 0.5;
g = exp(-pi*(([-15:15]'/t0).^2)) / t0;
S5 = fmspec([1;1]/2, 0.5, conv(g,ones(Ts,1)), Ts, N);

t0 = sqrt(log(2) / (2 * pi)) * Ts / 0.3;
g = exp(-pi*(([-15:15]'/t0).^2)) / t0;
S3 = fmspec([1;1]/2, 0.5, conv(g,ones(Ts,1)), Ts, N);

t0 = sqrt(log(2) / (2 * pi)) * Ts / 0.2;
g = exp(-pi*(([-23:23]'/t0).^2)) / t0;
S2 = fmspec([1;1]/2, 0.5, conv(g,ones(Ts,1)), Ts, N);

SM = fmspec([1;1]/2, 0.5, [0.01; ones(Ts,1); 0.01], Ts, N);

% Calculate QPSK spectrum.
fzero = 0.5;
fmax = 2.5;
df = fzero * 0.02;
f = [(0.5*df):df:(fmax+0.5*df)];
fpi = f * (pi / fzero);
SQ = ((sin(fpi) ./ fpi).^2) / fzero;

t=0:(N*2.5/Ts);
t1 = t+N/2+1;
plot(t*Ts/N,10*log10(max(1e-10,S2(t1))),'-b');
axis('normal')
axis([0 2.5 -100 10])
set(gca,'position',[0.15 0.17 0.7 0.8])
set(gca,'DefaultTextFontSize',14);
grid on
hold on
plot(t*Ts/N,10*log10(max(1e-10,S5(t1))),'-k');
plot(t*Ts/N,10*log10(max(1e-10,S3(t1))),'-r');
plot(t*Ts/N,10*log10(max(1e-10,SM(t1))),'color',[1 0 1]);
plot (f, 10*log10(max(1e-10,SQ)),'-','color',[0 0.7 0]);
hold off

text(-0.1,-45,'dB','horiz','right')
xlabel('Frequency relative to carrier / bit rate')
text(2.25,-20,' QPSK','horiz','center','vert','bottom','color',[0 0.7 0])
text(2.5,-35,' MSK','horiz','left','color',[1 0 1])
text(2.5,-87,' 0.5R GMSK','horiz','left','color','k')
text(1.68,-85,' 0.3R GMSK','horiz','left','color','r')
text(1.25,-85,' 0.2R GMSK ','horiz','right','color','b')
text(1.25,-115,...
 'Fig 4.5: Power spectra of QPSK, MSK, 0.5R GMSK, 0.3R GMSK and 0.2R GMSK.',...
  'horiz','center','vert','top')

if printon, print -deps \1ngk\tex\3f4digmod\3f4f4p5.eps, end

return
