% fig5p4.m
% Display QPSK modulation, 16-QAM and 64-QAM on same energy-per-bit scale.

% Display QPSK phasors.

if exist('printon') ~= 1, printon = 0; end

global dtime
dtime = 0.1;

imax = 16;
xb = [-1 1];

% Calculate sizes of the 3 constellations:
m = 1:3;
M = 2.^m;
vratios = sqrt(3*m ./ (M.^2 - 1)) .* [2 4 8]
widths = (0.94 * vratios / sum(vratios));
heights = widths * 1.34;

setfig(1)
posvec = [0.02 0.5-heights(1)/2 widths(1) heights(1)];
subplot('position', posvec);
% plot3df([xb 0 j*xb 0], 2, 'QPSK components')
xc = [xb-j  xb+j  0];
plot3df(xc, 2, 'QPSK', posvec)
text(1,0,'1','vert','top','horiz','center');
text(-1,0,'-1','vert','top','horiz','center');
text(0,1,'j ','vert','middle','horiz','right');
text(0,-1,'-j ','vert','middle','horiz','right');
% text(1,1,' 00','vert','bottom','horiz','left');
% text(-1,1,'10 ','vert','bottom','horiz','right');
% text(1,-1,' 01','vert','top','horiz','left');
% text(-1,-1,'11 ','vert','top','horiz','right');
axis off
drawnow

% Display 16-QAM phasors.

posvec = [0.03+widths(1) 0.5-heights(2)/2 widths(2) heights(2)];
subplot('position', posvec);
xb = [-1.5:1.5];
% plot3df([xb 0 j*xb 0], 2, '16-QAM components')
% for x=xb,
%   text(x,0,int2str(x*2),'vert','top','horiz','center');
% end
% for y=xb([1 4]),
%   text(0,y,[int2str(y*2) 'j '],'vert','middle','horiz','right');
% end
% text(0,-0.5,'-j ','vert','middle','horiz','right');
% text(0,0.5,'j ','vert','middle','horiz','right');
% pause

xc = [xb-1.5*j	xb-0.5*j  xb+0.5*j  xb+1.5*j  0];
plot3df(xc, 2, '16-QAM', posvec)
for i = -1:1,
  line([i -2;i 2],[-2 i; 2 i],'color',[0 0.7 0], ...
    'linestyle',':','erase','none');
end

for x=xb,
  text(x,0,int2str(x*2),'vert','top','horiz','center');
end
for y=xb([1 4]),
  text(0,y,[int2str(y*2) 'j '],'vert','middle','horiz','right');
end
text(0,-0.5,'-j ','vert','middle','horiz','right');
text(0,0.5,'j ','vert','middle','horiz','right');
code = ['11';'10';'00';'01'];
% for i=1:4,
%   text(xb(i),1.6,code(i,:),'vert','bottom','horiz','center');
%   text(1.6,xb(i),code(i,:),'vert','middle','horiz','left');
% end
drawnow

% Display 64-QAM phasors.

posvec = [0.04+sum(widths(1:2)) 0.5-heights(3)/2 widths(3) heights(3)];
subplot('Position', posvec);

xb = [-1.75:0.5:1.75];
% plot3df([xb 0 j*xb 0], 2, '64-QAM components')
% for x=xb,
%   text(x,0,int2str(x*4),'vert','top','horiz','center');
% end
% for y=xb([1:3 6:8]),
%   text(0,y,[int2str(y*4) 'j '],'vert','middle','horiz','right');
% end
% text(0,-0.25,'-j ','vert','middle','horiz','right');
% text(0,0.25,'j ','vert','middle','horiz','right');
% pause

xc = [xb-1.75*j  xb-1.25*j  xb-0.75*j  xb-0.25*j  xb+0.25*j  xb+0.75*j...
 xb+1.25*j  xb+1.75*j  0];
plot3df(xc, 2, '64-QAM', posvec)
pause
for i = -1.5:0.5:1.5,
  line([i -2;i 2],[-2 i; 2 i],'color',[0 0.7 0], ...
    'linestyle',':','erase','none');
end

code = ['110';'111';'101';'100';'000';'001';'011';'010'];
% for i=1:8,
%   text(xb(i),1.8,code(i,:),'vert','bottom','horiz','center');
%   text(1.8,xb(i),code(i,:),'vert','middle','horiz','left');
% end
for x=xb,
  text(x,0,int2str(x*4),'vert','top','horiz','center');
end
for y=xb([1:3 6:8]),
  text(0,y,[int2str(y*4) 'j '],'vert','middle','horiz','right');
end
text(0,-0.25,'-j ','vert','middle','horiz','right');
text(0,0.25,'j ','vert','middle','horiz','right');

if printon,
  print -depsc \1ngk\tex\e5mod\i5f5p4.eps
end
