% i5f5p5.m
% Plot error rates of MFSK and PSK .

if exist('printon') ~= 1, printon = 0; end

xmax = 20;
ebno = [0:0.2:xmax]';

% x is voltage SNR, sqrt(Eb / No).
x = exp(ebno * (log(10) / 20));
pbepsk = qfunc(x * sqrt(2));
pbedpsk = 2 * pbepsk .* (1 - pbepsk);

figure;
setfig(gcf)
set(gcf,'DefaultTextFontSize',14)
set(gcf,'DefaultLineLineWidth',1)
semilogy(ebno, pbedpsk, '-k')

axis('normal')
axis([0 xmax 1e-6 1])
set(gca,'position',[0.15 0.25 0.8 0.7]);
set(gca,'YColor','k')

% pause
hold on

pfsk = 2 * exp(-0.5 * x .* x);
pbemfsk = zeros(length(pfsk),6);
for m = 1:6,
  pbemfsk(:,m) = 0.25 * (pfsk.^m);
end

semilogy(ebno, pbemfsk, '-')

% Plot thin lines from text to curves.
semilogy([8.4;11.5],[2.4e-4;2.4e-3],'-k','linewidth',0.5)

linesx = [ 9.3  9.8  9.5   3.8   4.8    5.4
           9.8 10.3 11.3   5.2   5.8    6.3];
linesy = [7e-3 7e-5 3e-6 2.2e-3 2.2e-4 2.2e-5
          1e-2 1e-4 1e-5   5e-3   5e-4   4e-5];
semilogy(linesx,linesy,'-','linewidth',0.5)

hold off

grid

set(gcf,'DefaultTextFontSize',14)

text(13,4e-3,'BPSK with','horiz','center','vert','bottom');
text(13,2e-3,'differential','horiz','center','vert','bottom');
text(13,1e-3,'coding','horiz','center','vert','bottom');

text(9.0,1e-2,'BFSK','vert','bottom');
text(9.6,1e-4,'4FSK','vert','bottom');
text(10.7,1e-5,'8FSK','vert','bottom');

text(4.8,2.2e-3,'16FSK','horiz','right','vert','top');
text(5.7,2.2e-4,'32FSK','horiz','right','vert','top');
text(6.5,2.2e-5,'64FSK','horiz','right','vert','top');


text(-2.5,8e-3,'Bit');
text(-2.5,4e-3,'error');
text(-2.5,2e-3,'rate');

xlabel('Energy per bit / Noise PSD, Eb / No (dB)')
text(10,3e-8,'Fig 5.5: Approximate bit error rate curves for MFSK.',...
 'horiz','center');

if printon,
  print -deps \1ngk\tex\3F4digmod\i5f5p5.eps
end
