function y = cont(x,mod)
% function y = cont(x,mod)
% Convert the columns of x into continuous functions, by adding
% multiples of mod at points where there is a discontinuity of 
% > mod/2.
% The abs mean value of each column is adjusted to be < mod/2.
% If mod is not specified, the default is 2*pi.

if nargin < 2, mod = 2*pi; end

[m,n] = size(x);
modb2 = mod/2;
y = zeros(m,n);

% Loop for each column.
for col=1:n,
  xc = diff(x(:,col));
  
% Remove differences > mod/2.
  f = find(xc > modb2);
  while isempty(f) == 0,    
    xc(f) = xc(f) - mod;
    f = find(xc > modb2);
  end
    
% Remove differences < -mod/2.
  f = find(xc < -modb2);
  while isempty(f) == 0,
    xc(f) = xc(f) + mod;
    f = find(xc < -modb2);
  end

% Reconstruct vector from differences and correct the mean value.
  xs = cumsum([x(1,col); xc]);
  xm = round(mean(xs)/mod) * mod;
  y(:,col) = xs - xm;
end

return

