% errint.m
% Figures for the Errint or Q(x) section of I5 Dig. Comms Course.

if exist('printon') ~= 1, printon = 0; end

xmax = 7;
dx = 0.02;
x = [xmax:-dx:dx];
nx = length(x);
qtrue = zeros(1,nx);

% Gaussian PDF.
f = exp(-0.5 * (x .* x)) / sqrt(2 * pi);

% Evaluate the function mid way between each point to allow use of Simpson's
% rule for integration.
x2 = x - 0.5 * dx;
f2 = exp(-0.5 * (x2 .* x2)) / sqrt(2 * pi);

% Perform integration using Simpson's rule.
qsimp = f ./ x;
dq = (f(1:(nx-1)) + 4 * f2(1:(nx-1)) + f(2:nx)) * (dx / 6);
qtrue = cumsum([qsimp(1)  dq]);

setfig(1)
set(gcf,'DefaultTextFontSize',14)
set(gcf,'DefaultLineLineWidth',1)
semilogy(x, qtrue, '-y', x, qsimp, '-c')

axis('normal')
axis([0 5 1e-6 1])
set(gca,'position',[0.1 0.2 0.85 0.75]);
grid on

text (0.8,0.2,'Q(x)','vert','top','horiz','right')
text(1.4,0.11,'simple approximation','vert','bottom')
xlabel('x')

text(2.5,1e-7,'Fig 3.8: Q(x) and the simple approximation exp(-x*x/2) / sqrt(2*pi)*x',...
  'horiz','center')

if printon,
  print -deps \1ngk\tex\e5mod\i5f3p8.eps
else 
  pause
end


qf = qfunc(x);

plot (x, qf ./ qtrue, '-y')

axis('normal')
axis([0 5 0.995 1.005])
set(gca,'position',[0.1 0.2 0.85 0.75]);
grid on

xlabel('x')

text(2.5,0.9935,'Fig 3.9: The ratio of the improved approximation of Q(x) to its true value',...
  'horiz','center')

if printon,
  print -deps \1ngk\tex\e5mod\i5f3p9.eps
end
