% eyegmsk.m

% Create an eye diagram at an ideal MSK detector for a Gaussian filtered
% MSK signal for a variety of filter bandwidths.

Ts = 20;
% BW = 0.3;
nbits = 3;
ns = nbits * Ts;

% For 0.3R GMSK, note that from Couch endpapers:
%   exp(-pi*(t/t0)^2)  <->  t0 * exp(-pi*(f*t0)^2)
% Therefore t0 = sqrt(log(2) / (2*pi)) / f3db, so we use:
 
t0 = sqrt(log(2) / (2 * pi)) * Ts / BW;
g = exp(-pi*(([-ns:ns]'/t0).^2)) / t0;
g1 = conv(g, ones(Ts,1)/Ts);
gns = g(1)

nb2 = 5;

% Generate a matrix of 2^nb2 bit patterns.
b = [1:(2^nb2)] - 1;
bb = [];
for i = 1:nb2,
  bb = [bb; 2*rem(b,2)-1];
  b = floor(b/2);
end
bb = bb(:);


% Upsample by Ts.
bb = kron(bb, ones(Ts,1)/Ts);

% Convolve the columns of bb with g.
bc = conv(bb,g);

% Integrate bc and scale by the mod index, 0.5 to give the phase trajectory.
bph = 0.5 * cumsum(bc);

% Find the quadrature phase components.
bq = sin(bph * pi);

% Convolve the columns of bb with the MSK matched filter h.
h = cos([-Ts:Ts]' * 0.5 * pi / Ts) / Ts;
bm = conv(bq,h);

% Plot the eye diagram.
t1 = 7*Ts + [-Ts:Ts];
t = [-Ts:Ts]/Ts;
% figure(gcf)
plot(t,bm(t1,:),'y')
hold on
imax = round(length(bm)/(2*Ts)) - 12;
for i = 1:imax,
  t1 = t1 + 2*Ts;
  plot(t,bm(t1,:),pcolour);
end

grid on
hold off