function plot3d(x, p, dim, name)
% function plot3d(x, p, dim, name)
% Movie to show phasors and x in 2D or 3D.

global dtime

warning off % Disable warnings for ('erasemode','none') in line().

colour = defcol;
imax = length(x);
di = 5 / imax;
thx = pi / 6;
thz = -thx;
if dim==3,
  c3d = [cos(thx) 0 cos(thz); sin(thx) 1 sin(thz)]';
else
  c3d = [1 0 0; 0 1 0]';
end
hold off
if dim==3,
  xofst = 4;
  xmax = imax*di+xofst+1;
  ymax = 2 + 0.5 * xofst;
  ymin = -0.75*(xmax+2) + ymax;
  t = 1:5;
else
  xofst = 3;
  xmax = 10 / 3;
  ymax = 2;
  ymin = -2;
  t = [1 2 4];
end
ax = [-2 0 0; 2.2 0 0; 0 -2 0; 0 2 0; 0 0 -1; 0 0 imax*di+0.5] * c3d;
ax2 = [xofst -2 0; xofst 2 0; xofst 0 -1; xofst 0 imax*di+0.5] * c3d;
arrow = [0  1  0.9+j*0.05  0.9-j*0.05  1]';
pl = zeros(2,1);
line1 = [0 1]';
line1 = arrow;
xl = zeros(2,1);

figure(gcf)
% hold off
axx = reshape([ax;ax2],2,10);
plot(axx(:,t),axx(:,t+5),'color',colour(1,:),'erase','none');
axis([-2 xmax ymin ymax])
axis('normal')
axis('off')
set(gca,'Xtick',[],'Ytick',[])
set(gca,'position',[0.125 0.1 0.75 0.84])
set(gca,'DefaultTextFontSize',16);

text(ax(2,1),ax(2,2),' i')
text(ax(4,1),ax(4,2)*0.95,' q')
text(ax2(2,1),ax2(2,2)*0.95,' x')

if dim==3,
  text(ax(6,1),ax(6,2),' t')
  text(ax2(4,1),ax2(4,2),' t')
end

if nargin>=4, xlabel(name); end
% drawnow

for i=1:imax,
  if dim==3, perspec = 1 / (1 - 0.2 * i / imax); else perspec = 1; end
  pnew = (p(i) * perspec) * arrow;
  pl(2) = pnew(2);
  pnew2 = [real(pnew) imag(pnew) di*(i-1)*ones(length(pnew),1)] * c3d;
  pl2 = [real(pl) imag(pl) [max(i-2,0); i-1]*di] * c3d;
  xnew = (real(x(i)) * perspec) * line1 * j;
  xl(2) = xnew(2);
  xnew2 = [xofst+real(xnew) imag(xnew) di*(i-1)*ones(length(xnew),1)] * c3d;
  xl2 = [xofst*ones(2,1) imag(xl) [max(i-2,0); i-1]*di] * c3d;

  if i == 1,
    h1 = line(pnew2(:,1),pnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    h2 = line(xnew2(:,1),xnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    t = [2 2];
    line(pl2(t,1),pl2(t,2),'color',colour(4,:),'erase','none','Linewidth',2);
    line(xl2(t,1),xl2(t,2),'color',colour(4,:),'erase','none','Linewidth',2);
    % pause 

  else
    set(h1,'color',colour(3,:));
    set(h2,'color',colour(3,:));
    h1 = line(pnew2(:,1),pnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    h2 = line(xnew2(:,1),xnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    line(pl2(:,1),pl2(:,2),'color',colour(4,:),'erase','none','Linewidth',2);
    if dim==3, 
      line(xl2(:,1),xl2(:,2),'color',colour(4,:),'erase','none','Linewidth',2);
    end
  end
  drawnow

  pl(1) = pl(2);
  xl(1) = xl(2);
  if i < 4, pause;
  else delay(dtime);
  end
end
