function plot3de(p, dim, name, dt)
% function plot3de(p, dim, name, dt)
% Movie to show digital phasors in 2D or 3D with their inphase and quadrature
% components.

warning off % Disable warnings for ('erasemode','none') in line().

if nargin < 4, dt = 0; end
colour = defcol;
imax = length(p);
di = 4 / imax;
thx = pi / 6;
thz = -thx;
if dim==3,
  c3d = [cos(thx) 0 cos(thz); sin(thx) 1 sin(thz)]';
else
  c3d = [1 0 0; 0 1 0]';
end

if dim==3,
  xmin = -2;
  xmax = imax*di+1;
  ymax = 2;
  ymin = -0.75*(xmax+2) + ymax;
  t = 1:3;
else
  xmin = -2;
  xmax = 2;
  ymax = 2;
  ymin = -2;
  t = 1:2;
end
ax = [-2 0 0; 2 0 0; 0 -2 0; 0 2 0; 0 0 -1; 0 0 imax*di+1] * c3d;
arrow = [0  1  0.9+j*0.05  0.9-j*0.05  1]';
pl = zeros(2,1);

figure(gcf)
axx = reshape(ax,2,6);
plot(axx(:,t),axx(:,t+3),'color',colour(1,:),'linestyle',':','erase','none');

axis([xmin xmax ymin ymax])
axis('off')
set(gca,'Xtick',[],'Ytick',[]);
set(gca,'position',[0.05 0.1 0.9 0.8])
set(gca,'DefaultTextFontSize',16);
if dim==2, axis('square'); end

text(ax(2,1),ax(2,2),' i')
text(ax(4,1),ax(4,2),'q','vert','bottom','horiz','center')
if dim==3, text(ax(6,1),ax(6,2),' t'); end
if nargin>=3, xlabel(name); end

% drawnow

for i=1:imax,
  if dim==3, perspec = 1 / (1 - 0.2 * i / imax); else perspec = 1; end
  pnew = (p(i) * perspec) * arrow;
  inew = (real(p(i)) * perspec) * arrow;
  qnew = (j * imag(p(i)) * perspec) * arrow;
  pnew2 = [real(pnew) imag(pnew) di*(i-1)*ones(5,1)] * c3d;
  inew2 = [real(inew) imag(inew) di*(i-1)*ones(5,1)] * c3d;
  qnew2 = [real(qnew) imag(qnew) di*(i-1)*ones(5,1)] * c3d;

  if i > 1,
    set(h1,'color',colour(1,:));
    set(h2,'color',colour(1,:));
    set(h3,'color',colour(3,:));
  end
  h1 = line(inew2(:,1),inew2(:,2),'color',colour(2,:),'linestyle','-',...
   'erase','none');
  h2 = line(qnew2(:,1),qnew2(:,2),'color',colour(2,:),'linestyle','-',...
   'erase','none');
  h3 = line(pnew2(:,1),pnew2(:,2),'color',colour(4,:),'erase','none');
  drawnow

  if i > 1 & nargin > 3,
    delay(dt)
  else
    pause
  end
end
