function spec3d(P, fc, dim, name)
% function spec3d(x, p, dim, name)
% Movie to show phasor and signal spectra in 2D or 3D.

global dtime

colour = defcol;
imax = length(P);
di = 2 / imax;
thx = pi / 6;
thz = -thx;
if dim==3,
  c3d = [cos(thx) 0 cos(thz); sin(thx) 1 sin(thz)]';
else
  c3d = [1 0 0; 0 1 0]';
end
hold off
  xofst = 5;
  fmax = (imax-1)*di/2;
  fmin = -fmax;
  xmax = fmax+xofst+1.3;
  xmin = fmin-fc;
  ymax = 3 + 0.5 * xofst;
  ymin = -0.75*(xmax - xmin) + ymax;
  df = di;
  t = 1:8;
fcax = 1.5;
ax = [-2 0 0; 2 0 0; 0 -2 0; 0 2 0; 0 0 -fmax-fc-1; 0 0 fmax+fc+1;....
 0 -fcax -fc; 0 fcax -fc; 0 -fcax fc; 0 fcax fc] * c3d;
ax2 = [xofst -2 0; xofst 3 0; xofst 0 -fmax-1; xofst 0 fmax+1; ....
 xofst-2 0 0; xofst+2 0 0] * c3d;
pl = zeros(2,1);
line1 = [0 1]';
spl = zeros(2,1);
sml = zeros(2,1);

figure(gcf)
axx = reshape([ax;ax2],2,16);
plot(axx(:,t),axx(:,t+8),'color',colour(1,:),'erase','none');
axis([xmin xmax ymin ymax])
axis('normal')
axis('off')
set(gca,'Xtick',[],'Ytick',[])
set(gca,'position',[0.1 0.1 0.8 0.8])
set(gca,'DefaultTextFontSize',16);

text(ax(2,1),ax(2,2),' Re[S]')
text(ax(4,1),ax(4,2)*0.95,' Im[S]')
text(ax2(2,1),ax2(2,2)*0.95,' Im[P]')
text(ax2(6,1),ax2(6,2),' Re[P]')
if dim==3,
  text(ax(6,1),ax(6,2),' f')
  text(ax2(4,1),ax2(4,2),' f')
  text(ax(8,1),ax(8,2),'-fc','horiz','center','vert','bottom')
  text(ax(10,1),ax(10,2),'fc','horiz','center','vert','bottom')
end
if nargin>=4, xlabel(name); end

i = 0;
if dim==3, perspec = 0.1 / (fmax + fc); else perspec = 0; end
for f=fmin:df:fmax,
  i = i + 1;
  pnew = (P(i) / (1 - (f-xofst) * perspec)) * line1;
  pl(1) = pl(2);
  pl(2) = pnew(2);
  pnew2 = [real(pnew)+xofst imag(pnew) f*ones(2,1)] * c3d;
  pl2 = [real(pl)+xofst imag(pl) [f-df; f]] * c3d;
  spnew = (0.5 * P(i) / (1 - (f+fc) * perspec)) * line1;
  spl(1) = spl(2);
  spl(2) = spnew(2);
  spnew2 = [real(spnew) imag(spnew) (f+fc)*ones(2,1)] * c3d;
  spl2 = [real(spl) imag(spl) [f+fc-df; f+fc]] * c3d;
  smnew = (0.5 * conj(P(i)) / (1 - (-f-fc) * perspec)) * line1;
  sml(1) = sml(2);
  sml(2) = smnew(2);
  smnew2 = [real(smnew) imag(smnew) (-f-fc)*ones(2,1)] * c3d;
  sml2 = [real(sml) imag(sml) [-f-fc+df; -f-fc]] * c3d;

  if f == fmin,
    h1 = line(pnew2(:,1),pnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    h2 = line(spnew2(:,1),spnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    h3 = line(smnew2(:,1),smnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    % pause 

  else
    set(h1,'color',colour(3,:));
    set(h2,'color',colour(3,:));
    set(h3,'color',colour(3,:));
    h1 = line(pnew2(:,1),pnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    h2 = line(spnew2(:,1),spnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    h3 = line(smnew2(:,1),smnew2(:,2),'color',colour(2,:),'erase','none','Linewidth',2);
    line(pl2(:,1),pl2(:,2),'color',colour(4,:),'erase','none','Linewidth',2);
    line(spl2(:,1),spl2(:,2),'color',colour(4,:),'erase','none','Linewidth',2);
    line(sml2(:,1),sml2(:,2),'color',colour(4,:),'erase','none','Linewidth',2);
  end
  drawnow

  if i < 4, pause;
  else delay(dtime);
  end
end
